
Overview
===========


:Title: DREAM5 - Network Inference Challenge 
:Nickname: D5C4
:Summary: Infer simulated and in-vivo regulation networks
:SubChallenges: None 
:Synapse page: https://www.synapse.org/#!Synapse:syn2787209


.. contents::


Scoring
---------

::

    from dreamtools import D5C4
    s = D5C4()
    filename = s.download_template() 
    s.score(filename) 


